import ajax from "@/utils/request.js";
import fileDownload from "@/utils/download.js";

// 全国接口

/**
 *
 * @param {*} data
 * @returns {AxjxPromise}
 */
export function selectDate(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/performance/absepg_filter",
    method: "POST",
    data,
  });
}

/**
 * 频道全天节目
 * 表格查询
 * @props {}
 * @return {AxjxPromise}
 */
export function allDayEpg(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/broadcast/list",
    method: "get",
    data,
  });
}

/**
 * 节目查询
 * @props kw&ft
 * @return {AxjxPromise}
 */
export function overlapSearchTitle(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/search_suggest?" + data,
    method: "GET",
  });
}

/**
 * 节目查询
 * @props kw&ft
 * @return {AxjxPromise}
 */
export function epgAggregate(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/EpgListByCaIdGrowAction?" + data,
    method: "GET",
  });
}

// 重叠度
/**
 * 节目重叠度
 * 图表查询
 * @props epg_ids=&area_id=
 * @return {AxjxPromise}
 */
export function overlap(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/ProUserOverlapAction?" + data,
    method: "GET",
  });
}
// 电视剧排播信息及表现（全国）
/**
 * 节目排行-同时段频道
 * @props epg_id=&area_id=
 * @return {AxjxPromise}
 */
export function summary(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/EpgPeriodLeaderboardTvAction?" + data,
    method: "GET",
  });
}
/**
 * 节目排行-同时段频道导出
 * @props epg_id=&area_id=&domain=pro.eye.kuyun.com%2F&download=csv&page_no=1&page_size=10000
 */
export function summaryExport(data, fileName) {
  fileDownload(
    {
      urlType: "kuyunApi",
      url:
        "/api/evaluation/eye/download/api/eye/EpgPeriodLeaderboardTvAction?" +
        data,
      method: "GET",
    },
    fileName
  );
}
/**
 * 节目排行-同时段节目
 * @props epg_id=&area_id=
 * @return {AxjxPromise}
 */
export function program(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/EpgPeriodLeaderboardAction?page_no=1&" + data,
    method: "GET",
  });
}
/**
 * 节目排行-同时段节目导出
 * @props epg_id=&area_id=&domain=pro.eye.kuyun.com%2F&download=csv&page_no=1&page_size=10000
 */
export function programExport(data, fileName) {
  fileDownload(
    {
      urlType: "kuyunApi",
      url:
        "/api/evaluation/eye/download/api/eye/EpgPeriodLeaderboardAction?" +
        data,
      method: "GET",
    },
    fileName
  );
}
/**
 * 节目排行-同时段多节目
 * @props epg_ids=&area_id=
 * @return {AxjxPromise}
 */
export function programs(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/performance/epgkpi/summary?" + data,
    method: "GET",
  });
}
/**
 * 节目排行-同时段节目导出
 * @props epg_ids=&area_id=&domain=api.eye.kuyun.com
 */
export function programsExport(data, fileName) {
  fileDownload(
    {
      urlType: "kuyunApi",
      url:
        "/api/evaluation/eye/download/performance/epgkpi/summary/download?" +
        data,
      method: "GET",
    },
    fileName
  );
}
//

/**
 * 抽象节目剧目分地区收视（全国）
 * @props epg_ids=&area_id=
 * @return {AxjxPromise}
 */
export function country(data) {
  return ajax({
    urlType: "kuyunApi",
    url: "/api/evaluation/eye/performance/absepgkpi",
    method: "POST",
    data,
  });
}


/**
 * 单期节目流入流出
 * @props epg_ids=&area_id=
 * @return {AxjxPromise}
 */
 export function singleProgram(data) {
    return ajax({
      urlType: "kuyunApi",
      url: "/api/evaluation/eye/EpgInputOutputAction?kpi=tv_ratings&" +data,
      method: "GET",
    });
  }